(raytracing)=

# Ray Tracing

The ray-tracing modules handle ray tracing simulations, incident angle calculations, PSF analysis and I/O.

(incidentanglesmodule)=

## incident_angles

```{eval-rst}
.. automodule:: ray_tracing.incident_angles
   :members:
```

(raytracingmodule)=

## ray_tracing

```{eval-rst}
.. automodule:: ray_tracing.ray_tracing
   :members:
```

(psfanalysismodule)=

## psf_analysis

```{eval-rst}
.. automodule:: ray_tracing.psf_analysis
   :members:
```

(psfparameteroptimisationmodule)=

## psf_parameter_optimisation

```{eval-rst}
.. automodule:: ray_tracing.psf_parameter_optimisation
   :members:
```

(mirror_panel_psfmodule)=

## mirror_panel_psf

```{eval-rst}
.. automodule:: ray_tracing.mirror_panel_psf
   :members:
```
